Optimizers
==========

The optimizers module contains the low-level fitting functions. Most users will use the high-level ``df.fit()`` interface, but these functions are available for advanced use cases.

.. automodule:: ezfit.optimizers
   :members:
   :undoc-members:
   :show-inheritance:

Note
----

These functions are typically called internally by ``FitAccessor.fit()``. Direct use is only recommended for advanced scenarios.
